**To delete one of your transcription jobs**

The following ``delete-transcription-job`` example deletes one of your transcription jobs. ::

    aws transcribe delete-transcription-job \
        --transcription-job-name your-transcription-job

This command produces no output.

For more information, see `DeleteTranscriptionJob <https://docs.aws.amazon.com/transcribe/latest/dg/API_DeleteTranscriptionJob.html>`__ in the *Amazon Transcribe Developer Guide*.